==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Dodaj dodatno lastnost</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Vrednost:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+190"/>
        <source>*VARIES*</source>
        <translation>*RAZLIČNO*</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+137"/>
        <source>No Selection</source>
        <translation>Ni izbrano</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Geometry</source>
        <translation>Geometrija</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Odvisne entitete</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Dodatno</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Index</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Odstrani to lastnost iz izbranih objektov</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Add custom property to selected objects</source>
        <translation>Izbranim objektom dodaj dodatno lastnost</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Levo</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Sredina</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Desno</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Poravnano</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Sredina</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation type="obsolete">Prilagodi</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Vrh</translation>
    </message>
    <message>
        <source>Base</source>
        <translation type="obsolete">Baza</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Dno</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <location line="+119"/>
        <source>Use auto measurement</source>
        <translation>Uporabi samodejne meritve</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location line="+317"/>
        <location line="+12"/>
        <source>Property Editor</source>
        <translation>Urejevalec lastnosti</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Izbor:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Move Selection to a New Layer</source>
        <translation>Premakni izbrano na drugo plast</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Handle:</source>
        <translation>Identifikator:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Dodaj dodatno lastnost</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Vrednost:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1318"/>
        <source>*VARIES*</source>
        <translation>*RAZLIČNO*</translation>
    </message>
    <message>
        <location line="-1130"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translation>Ni izbrano</translation>
    </message>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometrija</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Specifične lastnosti</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Odvisne entitete</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Dodatno</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Odstrani to lastnost iz izbranih objektov</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Vse</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Izbranim objektom dodaj dodatno lastnost</translation>
    </message>
    <message>
        <location line="+617"/>
        <source>Widgets</source>
        <translation>Gradniki</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Levo</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Sredina</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Desno</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Poravnano</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Sredina</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation type="obsolete">Prilagodi</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Vrh</translation>
    </message>
    <message>
        <source>Base</source>
        <translation type="obsolete">Baza</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Dno</translation>
    </message>
    <message>
        <location line="-481"/>
        <source>Auto</source>
        <translation>Samodejno</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Use auto measurement</source>
        <translation>Uporabi samodejne meritve</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Urejevalec lastnosti</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Izbor:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Splošno</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Splošne lastnosti</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Premakni izbrano na drugo plast</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Faktor tipa črte:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Zaščiteno:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>Identifikator:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Prikaži koordinate Z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Prikaži lastnosti trenutnega bloka in trenutne plasti</translation>
    </message>
</context>
</TS>
